package org.ow2.weblab.core.annotator;

/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2010 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

import java.net.URI;

import org.ow2.weblab.rdf.Value;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.rdf.XMLParser;


public class BaseAnnotator extends AbstractAnnotator {

	public static final String RDF_PREFIX = "rdf";
	public static final URI RDF_URI = XMLParser.buildURI("http://www.w3.org/1999/02/22-rdf-syntax-ns#");
	public static final String RDFS_PREFIX = "rdfs";
	public static final URI RDFS_URI = XMLParser.buildURI("http://www.w3.org/2000/01/rdf-schema#");

	public BaseAnnotator(final Resource resource) {
		super(resource);
	}

	public BaseAnnotator(final URI subject, final PieceOfKnowledge pieceOfKnowledge) {
		super(subject, pieceOfKnowledge);
	}

	public void writeType(final URI uri) {
		applyOperator(Operator.WRITE, RDF_PREFIX, RDF_URI, "type", URI.class, uri);
	}

	public Value<URI> readType() {
		return applyOperator(Operator.READ, RDF_PREFIX, RDF_URI, "type", URI.class, null);
	}

	public Value<String> readLabel() {
		return applyOperator(Operator.READ, RDFS_PREFIX, RDFS_URI, "label", String.class, null);
	}

	public void writeLabel(final String value) {
		applyOperator(Operator.WRITE, RDFS_PREFIX, RDFS_URI, "label", String.class, value);
	}

}
