package org.purl.dc.elements;

/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2010 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

import java.net.URI;
import java.util.Date;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.rdf.Value;
import org.ow2.weblab.rdf.XMLParser;

 /**
  * 
  */
public class DublinCoreAnnotator extends BaseAnnotator {

	protected static final String PREFIX = "dc";
	protected static final URI URI = XMLParser.buildURI("http://purl.org/dc/elements/1.1/");

	public DublinCoreAnnotator(URI subject, PieceOfKnowledge pieceOfKnowledge){
		super(subject,pieceOfKnowledge);
	}

	public DublinCoreAnnotator(Resource resource){
		super(resource);
	}

	/**
	 * Read the A name given to the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readTitle(){
		return applyOperator(Operator.READ, null,URI, TITLE, String.class, null);
	}


	/**
	 * Write the A name given to the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeTitle(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, TITLE, String.class, value);
	}


	/**
	 * Read the An entity primarily responsible for making the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readCreator(){
		return applyOperator(Operator.READ, null,URI, CREATOR, String.class, null);
	}


	/**
	 * Write the An entity primarily responsible for making the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeCreator(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, CREATOR, String.class, value);
	}


	/**
	 * Read the The topic of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readSubject(){
		return applyOperator(Operator.READ, null,URI, SUBJECT, String.class, null);
	}


	/**
	 * Write the The topic of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeSubject(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, SUBJECT, String.class, value);
	}


	/**
	 * Read the An account of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readDescription(){
		return applyOperator(Operator.READ, null,URI, DESCRIPTION, String.class, null);
	}


	/**
	 * Write the An account of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeDescription(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, DESCRIPTION, String.class, value);
	}


	/**
	 * Read the An entity responsible for making the resource available. 
	 * 
	 * @return a String
	 */
	public Value<String> readPublisher(){
		return applyOperator(Operator.READ, null,URI, PUBLISHER, String.class, null);
	}


	/**
	 * Write the An entity responsible for making the resource available.
	 * @param value a String
	 * @return a boolean
	 */
	public void writePublisher(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, PUBLISHER, String.class, value);
	}


	/**
	 * Read the An entity responsible for making contributions to the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readContributor(){
		return applyOperator(Operator.READ, null,URI, CONTRIBUTOR, String.class, null);
	}


	/**
	 * Write the An entity responsible for making contributions to the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeContributor(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, CONTRIBUTOR, String.class, value);
	}


	/**
	 * Read the A point or period of time associated with an event in the lifecycle of the resource. 
	 * 
	 * @return a String
	 */
	public Value<Date> readDate(){
		return applyOperator(Operator.READ, null,URI, DATE, Date.class, null);
	}


	/**
	 * Write the A point or period of time associated with an event in the lifecycle of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeDate(Date value){
		applyOperator(Operator.WRITE, PREFIX,URI, DATE, Date.class, value);
	}


/**
	 * Read the The file format, physical medium, or dimensions of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readFormat(){
		return applyOperator(Operator.READ, null,URI, FORMAT, String.class, null);
	}


	/**
	 * Write the The file format, physical medium, or dimensions of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeFormat(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, FORMAT, String.class, value);
	}


	/**
	 * Read the An unambiguous reference to the resource within a given context. 
	 * 
	 * @return a String
	 */
	public Value<String> readIdentifier(){
		return applyOperator(Operator.READ, null,URI, IDENTIFIER, String.class, null);
	}


	/**
	 * Write the An unambiguous reference to the resource within a given context.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeIdentifier(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, IDENTIFIER, String.class, value);
	}


	/**
	 * Read the A related resource from which the described resource is derived. 
	 * 
	 * @return a String
	 */
	public Value<String> readSource(){
		return applyOperator(Operator.READ, null,URI, SOURCE, String.class, null);
	}


	/**
	 * Write the A related resource from which the described resource is derived.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeSource(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, SOURCE, String.class, value);
	}


	/**
	 * Read the A language of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readLanguage(){
		return applyOperator(Operator.READ, null,URI, LANGUAGE, String.class, null);
	}


	/**
	 * Write the A language of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeLanguage(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, LANGUAGE, String.class, value);
	}


	/**
	 * Read the A related resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readRelation(){
		return applyOperator(Operator.READ, null,URI, RELATION, String.class, null);
	}


	/**
	 * Write the A related resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeRelation(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, RELATION, String.class, value);
	}


	/**
	 * Read the The spatial or temporal topic of the resource, the spatial applicability of the resource, or the jurisdiction under which the resource is relevant. 
	 * 
	 * @return a String
	 */
	public Value<String> readCoverage(){
		return applyOperator(Operator.READ, null,URI, COVERAGE, String.class, null);
	}


	/**
	 * Write the The spatial or temporal topic of the resource, the spatial applicability of the resource, or the jurisdiction under which the resource is relevant.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeCoverage(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, COVERAGE, String.class, value);
	}


	/**
	 * Read the Information about rights held in and over the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readRights(){
		return applyOperator(Operator.READ, null,URI, RIGHTS, String.class, null);
	}


	/**
	 * Write the Information about rights held in and over the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeRights(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, RIGHTS, String.class, value);
	}


	protected static final String TITLE = "title";
	protected static final String CREATOR = "creator";
	protected static final String SUBJECT = "subject";
	protected static final String DESCRIPTION = "description";
	protected static final String PUBLISHER = "publisher";
	protected static final String CONTRIBUTOR = "contributor";
	protected static final String DATE = "date";
	protected static final String TYPE = "type";
	protected static final String FORMAT = "format";
	protected static final String IDENTIFIER = "identifier";
	protected static final String SOURCE = "source";
	protected static final String LANGUAGE = "language";
	protected static final String RELATION = "relation";
	protected static final String COVERAGE = "coverage";
	protected static final String RIGHTS = "rights";

}

